@@ -1,13 +1,15 @@
 """Inspect photos selected in Photos """
 
+from __future__ import annotations
+
 import functools
+import pathlib
 import re
 from fractions import Fraction
 from multiprocessing import Process, Queue
 from queue import Empty
 from time import gmtime, sleep, strftime
-from typing import List, Optional, Tuple
-import pathlib
+from typing import Generator, List, Optional, Tuple
 
 import bitmath
 import click
@@ -19,13 +21,14 @@ from rich.live import Live
 from rich.panel import Panel
 
 from osxphotos import PhotoInfo, PhotosDB
-from osxphotos._constants import _UNKNOWN_PERSON
+from osxphotos._constants import _UNKNOWN_PERSON, search_category_factory
 from osxphotos.rich_utils import add_rich_markup_tag
 from osxphotos.text_detection import detect_text as detect_text_in_photo
 from osxphotos.utils import dd_to_dms_str
 
+from .cli_params import DB_OPTION, THEME_OPTION
 from .color_themes import get_theme
-from .common import DB_OPTION, THEME_OPTION, get_photos_db
+from .common import get_photos_db
 
 # global that tracks UUID being inspected
 CURRENT_UUID = None
@@ -35,6 +38,17 @@ bold = add_rich_markup_tag("bold")
 dim = add_rich_markup_tag("dim")
 
 
+def add_cyclic_color_tag(values: list[str]) -> Generator[str, None, None]:
+    """Add a rich markup tag to each str in values, cycling through a set of colors"""
+    # reuse some colors already in the theme
+    # these are chosen for contrast to easily associate scores and values
+    colors = ["change", "count", "filepath", "filename"]
+    color_tags = [add_rich_markup_tag(color) for color in colors]
+    modidx = len(color_tags)
+    for idx, val in enumerate(values):
+        yield color_tags[idx % modidx](val)
+
+
 def extract_uuid(text: str) -> str:
     """Extract a UUID from a string"""
     if match := re.search(
@@ -52,6 +66,22 @@ def trim(text: str, pad: str = "") -> str:
     return text if len(text) <= width else f"{text[: width- 3]}..."
 
 
+def format_search_info(photo: PhotoInfo) -> str:
+    """Format search info for photo"""
+    categories = sorted(list(photo._db._db_searchinfo_categories.keys()))
+    search_info = photo.search_info
+    if not search_info:
+        return ""
+    search_info_strs = []
+    category_dict = search_category_factory(photo._db.photos_version).categories()
+    for category in categories:
+        if text := search_info._get_text_for_category(category):
+            text = ", ".join(t for t in text if t) if isinstance(text, list) else text
+            category_name = str(category_dict.get(category, category)).lower()
+            search_info_strs.append(f"{bold(category_name)}: {text}")
+    return ", ".join(search_info_strs)
+
+
 def inspect_photo(
     photo: PhotoInfo,
     detected_text: Optional[str] = None,
@@ -125,8 +155,10 @@ def inspect_photo(
             + f"{', '.join(dd_to_dms_str(*photo.location)) if photo.location[0] else '-'}",
             bold("Place: ") + f"{photo.place.name if photo.place else '-'}",
             bold("Categories/Labels: ") + f"{', '.join(photo.labels) or '-'}",
+            bold("Search Info: ") + format_search_info(photo),
         ]
     )
+
     properties.append(format_flags(photo))
     properties.append(format_albums(photo))
 
@@ -191,9 +223,15 @@ def format_templates(photo: PhotoInfo, templates: List[str]) -> str:
 
 def format_score_info(photo: PhotoInfo) -> str:
     """Format score_info"""
-    score_str = bold("Score: ")
+    score_str = bold("Scores: ")
     if photo.score:
-        score_str += f"[num]{photo.score.overall}[/]" if photo.score else "-"
+        # add color tags to each key: value pair to easily associate keys/values
+        score_values = add_cyclic_color_tag(
+            [f"{k}: {float(v):.2f}" for k, v in photo.score.asdict().items()]
+        )
+        score_str += ", ".join(score_values)
+    else:
+        score_str += "-"
     return score_str
 
 
