@@ -1,6 +1,4 @@
-"""
-PhotoInfo class
-Represents a single photo in the Photos library and provides access to the photo's attributes
+""" PhotoInfo class: Represents a single photo in the Photos library and provides access to the photo's attributes
 PhotosDB.photos() returns a list of PhotoInfo objects
 """
 
@@ -10,18 +8,20 @@ import contextlib
 import dataclasses
 import datetime
 import json
-import logging
 import os
 import os.path
 import pathlib
 import plistlib
 from datetime import timedelta, timezone
 from functools import cached_property
-from typing import Dict, Optional
+from typing import Any, Dict, Optional
+import logging
 
 import yaml
 from osxmetadata import OSXMetaData
 
+import osxphotos
+
 from ._constants import (
     _DB_TABLE_NAMES,
     _MOVIE_TYPE,
@@ -68,6 +68,8 @@ from .utils import _get_resource_loc, hexdigest, list_directory
 
 __all__ = ["PhotoInfo", "PhotoInfoNone"]
 
+logger = logging.getLogger("osxphotos")
+
 
 class PhotoInfo:
     """
@@ -75,10 +77,10 @@ class PhotoInfo:
     including keywords, persons, albums, uuid, path, etc.
     """
 
-    def __init__(self, db=None, uuid=None, info=None):
-        self._uuid = uuid
-        self._info = info
-        self._db = db
+    def __init__(self, db: "osxphotos.PhotosDB", uuid: str, info: dict[str, Any]):
+        self._uuid: str = uuid
+        self._info: dict[str, Any] = info
+        self._db: "osxphotos.PhotosDB" = db
         self._verbose = self._db._verbose
 
     @property
@@ -245,7 +247,7 @@ class PhotoInfo:
                 photopath = self._path_edited_5()
 
             if photopath is not None and not os.path.isfile(photopath):
-                logging.debug(
+                logger.debug(
                     f"edited file for UUID {self._uuid} should be at {photopath} but does not appear to exist"
                 )
                 photopath = None
@@ -285,7 +287,7 @@ class PhotoInfo:
                 filename = f"{self._uuid}_2_0_a.mov"
             else:
                 # don't know what it is!
-                logging.debug(f"WARNING: unknown type {self._info['type']}")
+                logger.debug(f"WARNING: unknown type {self._info['type']}")
                 return None
 
             return os.path.join(library, "resources", "renders", directory, filename)
@@ -332,7 +334,7 @@ class PhotoInfo:
             try:
                 photopath = self._get_predicted_path_edited_4()
             except ValueError as e:
-                logging.debug(f"ERROR: {e}")
+                logger.debug(f"ERROR: {e}")
                 photopath = None
 
             if photopath is not None and not os.path.isfile(photopath):
@@ -346,12 +348,12 @@ class PhotoInfo:
 
             # check again to see if we found a valid file
             if photopath is not None and not os.path.isfile(photopath):
-                logging.debug(
+                logger.debug(
                     f"MISSING PATH: edited file for UUID {self._uuid} should be at {photopath} but does not appear to exist"
                 )
                 photopath = None
         else:
-            logging.debug(f"{self.uuid} hasAdjustments but edit_resource_id is None")
+            logger.debug(f"{self.uuid} hasAdjustments but edit_resource_id is None")
             photopath = None
 
         return photopath
@@ -400,7 +402,7 @@ class PhotoInfo:
                 None,
             )
         if photopath is None:
-            logging.debug(
+            logger.debug(
                 f"MISSING PATH: edited live photo file for UUID {self._uuid} does not appear to exist"
             )
         return photopath
@@ -496,7 +498,7 @@ class PhotoInfo:
                 self._db._masters_path, self._info["raw_info"]["imagePath"]
             )
         if not os.path.isfile(photopath):
-            logging.debug(
+            logger.debug(
                 f"MISSING PATH: RAW photo for UUID {self._uuid} should be at {photopath} but does not appear to exist"
             )
             photopath = None
@@ -912,7 +914,7 @@ class PhotoInfo:
             if self.live_photo and not self.ismissing:
                 live_model_id = self._info["live_model_id"]
                 if live_model_id is None:
-                    logging.debug(f"missing live_model_id: {self._uuid}")
+                    logger.debug(f"missing live_model_id: {self._uuid}")
                     photopath = None
                 else:
                     folder_id, file_id, nn_id = _get_resource_loc(live_model_id)
@@ -1196,7 +1198,7 @@ class PhotoInfo:
         """
 
         if self._db._db_version <= _PHOTOS_4_VERSION:
-            logging.debug(f"score not implemented for this database version")
+            logger.debug(f"score not implemented for this database version")
             return None
 
         try:
@@ -1342,7 +1344,7 @@ class PhotoInfo:
         """
 
         if self._db._db_version <= _PHOTOS_4_VERSION:
-            logging.debug(f"exif_info not implemented for this database version")
+            logger.debug(f"exif_info not implemented for this database version")
             return None
 
         try:
@@ -1369,7 +1371,7 @@ class PhotoInfo:
                 lens_model=exif["ZLENSMODEL"],
             )
         except KeyError:
-            logging.debug(f"Could not find exif record for uuid {self.uuid}")
+            logger.debug(f"Could not find exif record for uuid {self.uuid}")
             exif_info = ExifInfo(
                 iso=None,
                 flash_fired=None,
@@ -1441,7 +1443,7 @@ class PhotoInfo:
         """
 
         if self._db._db_version <= _PHOTOS_4_VERSION:
-            logging.debug(f"cloud_metadata not implemented for this database version")
+            logger.debug(f"cloud_metadata not implemented for this database version")
             return {}
 
         _, cursor = self._db.get_db_connection()
@@ -1451,6 +1453,21 @@ class PhotoInfo:
                 metadata = plistlib.loads(results[0])
         return metadata
 
+    @cached_property
+    def cloud_guid(self) -> str:
+        """Returns the GUID of the photo in iCloud (Photos 5+ only)"""
+        return self._info["cloudMasterGUID"]
+
+    @cached_property
+    def cloud_owner_hashed_id(self) -> str:
+        """Returns the hashed iCloud ID of the owner of the shared photo (Photos 5+ only)"""
+        return self._info["cloudownerhashedpersonid"]
+
+    @cached_property
+    def fingerprint(self) -> str:
+        """Returns fingerprint of original photo as a string"""
+        return self._info["masterFingerprint"]
+
     def detected_text(self, confidence_threshold=TEXT_DETECTION_CONFIDENCE_THRESHOLD):
         """Detects text in photo and returns lists of results as (detected text, confidence)
 
@@ -1836,6 +1853,9 @@ class PhotoInfo:
             "comments": comments,
             "likes": likes,
             "search_info": search_info,
+            "fingerprint": self.fingerprint,
+            "cloud_guid": self.cloud_guid,
+            "cloud_owner_hashed_id": self.cloud_owner_hashed_id,
         }
 
     def json(self):
