@@ -14,6 +14,8 @@ from typing import List, Optional, Tuple
 
 from textx import TextXSyntaxError, metamodel_from_file
 
+import osxphotos.template_counter as counter
+
 from ._constants import _UNKNOWN_PERSON, TEXT_DETECTION_CONFIDENCE_THRESHOLD
 from ._version import __version__
 from .datetime_formatter import DateTimeFormatter
@@ -151,6 +153,24 @@ TEMPLATE_SUBSTITUTIONS = {
     + "May be formatted using a python string format code. "
     + "For example, to format as a 5-digit integer and pad with zeros, use '{id:05d}' which results in "
     + "00001, 00002, 00003...etc. ",
+    "{counter}": "A sequential counter, starting at 0, that increments each time it is evaluated."
+    + "To start counting at a value other than 0, append append '(starting_value)' to the field name."
+    + "For example, to start counting at 1 instead of 0: '{counter(1)}'."
+    + "May be formatted using a python string format code."
+    + "For example, to format as a 5-digit integer and pad with zeros, use '{counter:05d(1)}'"
+    + "which results in 00001, 00002, 00003...etc."
+    + "You may also specify a stop value which causes the counter to reset to the starting value"
+    + "when the stop value is reached and a step size which causes the counter to increment by"
+    + "the specified value instead of 1. Use the format '{counter(start,stop,step)}' where start,"
+    + "stop, and step are integers. For example, to count from 1 to 10 by 2, use '{counter(1,11,2)}'."
+    + "Note that the counter stops counting when the stop value is reached and does not return the"
+    + "stop value. Start, stop, and step are optional and may be omitted. For example, to count"
+    + "from 0 by 2s, use '{counter(,,2)}'."
+    + "You may create an arbitrary number of counters by appending a unique name to the field name"
+    + "preceded by a period: '{counter.a}', '{counter.b}', etc. Each counter will have its own state"
+    + "and will start at 0 and increment by 1 unless otherwise specified."
+    + " Note: {counter} is not suitable for use with 'export' and '--update' "
+    + "as the counter associated with a photo may change between export sessions. See also {id}.",
     "{album_seq}": "An integer, starting at 0, indicating the photo's index (sequence) in the containing album. "
     + "Only valid when used in a '--filename' template and only when '{album}' or '{folder_album}' is used in the '--directory' template. "
     + 'For example \'--directory "{folder_album}" --filename "{album_seq}_{original_name}"\'. '
@@ -265,6 +285,8 @@ FILTER_VALUES = {
     + "e.g. join(): ['a', 'b', 'c'] => 'abc'.",
     "append(x)": "Append x to list of values, e.g. append(d): ['a', 'b', 'c'] => ['a', 'b', 'c', 'd'].",
     "prepend(x)": "Prepend x to list of values, e.g. prepend(d): ['a', 'b', 'c'] => ['d', 'a', 'b', 'c'].",
+    "appends(x)": "Append s[tring] Append x to each value of list of values, e.g. appends(d): ['a', 'b', 'c'] => ['ad', 'bd', 'cd'].",
+    "prepends(x)": "Prepend s[tring] x to each value of list of values, e.g. prepends(d): ['a', 'b', 'c'] => ['da', 'db', 'dc'].",
     "remove(x)": "Remove x from list of values, e.g. remove(b): ['a', 'b', 'c'] => ['a', 'c'].",
     "slice(start:stop:step)": "Slice list using same semantics as Python's list slicing, "
     + "e.g. slice(1:3): ['a', 'b', 'c', 'd'] => ['b', 'c']; slice(1:4:2): ['a', 'b', 'c', 'd'] => ['b', 'd']; "
@@ -301,6 +323,9 @@ FIELD_NAMES = (
 INPLACE_DEFAULT = ","
 PATH_SEP_DEFAULT = os.path.sep
 
+# globals for tracking {seq} substitutions
+_global_seq_count = 0
+
 PUNCTUATION = {
     "comma": ",",
     "semicolon": ";",
@@ -520,6 +545,8 @@ class PhotoTemplate:
             # process field arguments
             if ts.template.fieldarg is not None:
                 field_arg = ts.template.fieldarg.value
+            else:
+                field_arg = None
 
             # process delim
             if ts.template.delim is not None:
@@ -919,6 +946,8 @@ class PhotoTemplate:
                 start_id = int(field_arg) if field_arg is not None else 0
                 value = int(value) + start_id
                 value = format_str_value(value, subfield)
+        elif field.startswith("counter"):
+            value = counter.get_counter_value(field, subfield, field_arg)
         else:
             # if here, didn't get a match
             raise ValueError(f"Unhandled template value: {field}")
@@ -982,15 +1011,17 @@ class PhotoTemplate:
             raise SyntaxError(f"Unknown filter: {filter_}")
 
         if filter_ in [
-            "split",
-            "chop",
-            "chomp",
             "append",
+            "appends",
+            "chomp",
+            "chop",
+            "filter",
             "prepend",
+            "prepends",
             "remove",
             "slice",
+            "split",
             "sslice",
-            "filter",
         ] and (args is None or not len(args)):
             raise SyntaxError(f"{filter_} requires arguments")
 
@@ -1007,15 +1038,13 @@ class PhotoTemplate:
         elif filter_ == "braces":
             value = ["{" + v + "}" for v in values]
         elif filter_ == "parens":
-            value = ["(" + v + ")" for v in values]
+            value = [f"({v})" for v in values]
         elif filter_ == "brackets":
-            value = ["[" + v + "]" for v in values]
+            value = [f"[{v}]" for v in values]
         elif filter_ == "shell_quote":
             value = [shlex.quote(v) for v in values]
         elif filter_ == "split":
-            # split on delimiter
-            delim = args
-            if delim:
+            if delim := args:
                 new_values = []
                 for v in values:
                     new_values.extend(v.split(delim))
@@ -1026,15 +1055,15 @@ class PhotoTemplate:
             # chop off characters from the end
             try:
                 chop = int(args)
-            except ValueError:
-                raise SyntaxError(f"Invalid value for chop: {args}")
+            except ValueError as e:
+                raise SyntaxError(f"Invalid value for chop: {args}") from e
             value = [v[:-chop] for v in values] if chop else values
         elif filter_ == "chomp":
             # chop off characters from the beginning
             try:
                 chomp = int(args)
-            except ValueError:
-                raise SyntaxError(f"Invalid value for chomp: {args}")
+            except ValueError as e:
+                raise SyntaxError(f"Invalid value for chomp: {args}") from e
             value = [v[chomp:] for v in values] if chomp else values
         elif filter_ == "autosplit":
             # try to split keyword strings automatically
@@ -1069,6 +1098,12 @@ class PhotoTemplate:
         elif filter_ == "prepend":
             # prepend value to list
             value = [args] + values
+        elif filter_ == "appends":
+            # append value to each item in list
+            value = [f"{v}{args}" for v in values]
+        elif filter_ == "prepends":
+            # prepend value to each item in list
+            value = [f"{args}{v}" for v in values]
         elif filter_ == "remove":
             # remove value from list
             value = [v for v in values if v != args]
